Release History
===============

0.3.0 / 2017-11-14
------------------

* Support for changing spinner properties on the fly


0.2.0 / 2017-11-10
------------------

* Support all spinners from [cli-spinners](https://github.com/sindresorhus/cli-spinners)
* API changes:
    - `yaspin.spinner` -> `yaspin.yaspin`


0.1.0 / 2017-10-31
------------------

* First version
